pub enum CurveId {
Secp256k1,
}Expand description
Fixed curves supported by the native curve precompile.
Variants
Secp256k1
Implementations
Sourceimpl CurveId
impl CurveId
Sourcepub fn from_id(id: Felt) -> Option<Self>
pub fn from_id(id: Felt) -> Option<Self>
Returns the supported curve for an internal curve selector.
Sourcepub fn id(self) -> Felt
pub fn id(self) -> Felt
Returns the stable local curve selector retained for dispatch metadata.
Sourcepub const fn group_ptr(self) -> u32
pub const fn group_ptr(self) -> u32
Returns the VM-owned group configuration pointer used in curve VALUE tags.
Sourcepub const fn from_group_ptr(ptr: u32) -> Option<Self>
pub const fn from_group_ptr(ptr: u32) -> Option<Self>
Returns the supported curve for a VM-owned group configuration pointer.
Sourcepub const fn a_ptr(self) -> u32
pub const fn a_ptr(self) -> u32
Returns the VM-owned pointer for this curve’s first coefficient.
Sourcepub const fn b_ptr(self) -> u32
pub const fn b_ptr(self) -> u32
Returns the VM-owned pointer for this curve’s second coefficient.
Sourcepub const fn base_domain(self) -> UintDomain
pub const fn base_domain(self) -> UintDomain
Returns the base-field domain used by affine point coordinates.
Sourcepub const fn scalar_domain(self) -> UintDomain
pub const fn scalar_domain(self) -> UintDomain
Returns this curve’s scalar-field domain.
Sourcepub fn generator(self) -> CurvePoint
pub fn generator(self) -> CurvePoint
Returns this curve’s conventional generator point.
Sourcepub fn point_from_affine(
self,
x: Limbs,
y: Limbs,
) -> Result<CurvePoint, PrecompileError>
pub fn point_from_affine( self, x: Limbs, y: Limbs, ) -> Result<CurvePoint, PrecompileError>
Checked boundary dispatcher that constructs this curve’s canonical point for affine coordinates.
Sourcepub fn is_on_curve(self, point: &CurvePoint) -> bool
pub fn is_on_curve(self, point: &CurvePoint) -> bool
Returns whether point is a valid point on this curve.
Sourcepub fn add(
self,
lhs: CurvePoint,
rhs: CurvePoint,
) -> Result<CurvePoint, PrecompileError>
pub fn add( self, lhs: CurvePoint, rhs: CurvePoint, ) -> Result<CurvePoint, PrecompileError>
Trusted dispatcher that adds two canonical valid points on this curve.
Sourcepub fn neg(self, point: CurvePoint) -> Result<CurvePoint, PrecompileError>
pub fn neg(self, point: CurvePoint) -> Result<CurvePoint, PrecompileError>
Trusted dispatcher that negates a canonical valid point on this curve.
Sourcepub fn sub(
self,
lhs: CurvePoint,
rhs: CurvePoint,
) -> Result<CurvePoint, PrecompileError>
pub fn sub( self, lhs: CurvePoint, rhs: CurvePoint, ) -> Result<CurvePoint, PrecompileError>
Trusted dispatcher that subtracts two canonical valid points on this curve.
Sourcepub fn mul_scalar(
self,
point: CurvePoint,
scalar: Limbs,
) -> Result<CurvePoint, PrecompileError>
pub fn mul_scalar( self, point: CurvePoint, scalar: Limbs, ) -> Result<CurvePoint, PrecompileError>
Trusted dispatcher that multiplies a canonical valid point by a canonical scalar-field value.