pub enum UintNodeRef {
Value {
domain: UintDomain,
limbs: Limbs,
},
Add {
lhs: Digest,
rhs: Digest,
},
Sub {
lhs: Digest,
rhs: Digest,
},
Mul {
lhs: Digest,
rhs: Digest,
},
Eq {
lhs: Digest,
rhs: Digest,
},
}Expand description
Structural view of a uint precompile node.
Operation variants expose only the structural child digests in the node payload. Value variants expose the canonical domain and limbs after the same payload checks used by evaluation.
Variants
Value
Canonical uint value.
Add
Addition over two structural child digests.
Sub
Subtraction over two structural child digests.
Mul
Multiplication over two structural child digests.
Eq
Equality assertion over two structural child digests.